import 'dart:io';
import 'util.dart';

class _RouteInfo {
  final String method;
  final Function handler;
  const _RouteInfo(this.method, this.handler);
}

class Oxide {
  HttpServer _server;
  Map<String, _RouteInfo> _routes = Map();
  void start(int port) async {
    this._server = await HttpServer.bind("0.0.0.0", port);
    this._server.listen((request) => _handleRequests(request));
  }

  void setRoutes(List<Function> routeHandlers) {
    routeHandlers.forEach((handler) {
      this._routes[getRoutePath(handler)] =
          _RouteInfo(getRouteMethod(handler), handler);
    });
  }

  void _handleRequests(HttpRequest request) {
    _RouteInfo route = this._routes[request.requestedUri.path];
    if (route?.method == request.method) route.handler(request);
  }

  void shutdown() async {
    await this._server.close();
    this._routes.clear();
  }
}
